#
# spec file for package python-partd
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-partd
Version:        1.4.1
Release:        2.1
Summary:        Appendable key-value storage
License:        BSD-3-Clause
Group:          Development/Languages/Python
URL:            https://github.com/mrocklin/partd/
Source:         https://files.pythonhosted.org/packages/source/p/partd/partd-%{version}.tar.gz
BuildRequires:  %{python_module locket}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module toolz}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-locket
Requires:       python-toolz
Recommends:     python-blosc
Recommends:     python-numpy >= 1.9.0
Recommends:     python-pandas
Recommends:     python-pyzmq
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module pytest}
# /SECTION
%python_subpackages

%description
Key-value byte store with appendable values

Partd stores key-value pairs.
Values are raw bytes.
We append on old values.

Partd excels at shuffling operations.

%prep
%setup -q -n partd-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%files %{python_files}
%doc README.rst
%license LICENSE.txt
%{python_sitelib}/partd
%{python_sitelib}/partd-%{version}.dist-info

%changelog
* Sun Apr 21 2024 ecsos <ecsos@opensuse.org>
- Add %%{?sle15_python_module_pythons}
* Tue Dec 12 2023 Dirk Müller <dmueller@suse.com>
- update to 1.4.1:
  * Avoid deprecated is_datetime64tz_dtype from pandas
  * Update Python version classifiers
* Sun Sep 10 2023 Ben Greiner <code@bnavigator.de>
- Update to 1.4.0
  * no release notes
  * DataFrame._data deprecation in pandas (#65)
  * Use pickle for pandas Index with extension dtype (#64)
* Tue Oct  4 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to Version 1.3.0
  * Remove deprecated use of `Index._get_attributes_dict` (#60)
  * Avoid `pandas` testing deprecation warning (#59)
  * Add support for Python 3.9, drop support for Python 3.5 and 3.6 (#54)
  * Use `is_alive` in favour of `isAlive` for Python 3.9 compatibility (#53)
* Fri Aug 13 2021 Ben Greiner <code@bnavigator.de>
- update to 1.2.0
  * no release notes
  * fixes compatibility with pandas 1.3 -- gh#dask/partd#49
* Wed Mar 11 2020 Marketa Calabkova <mcalabkova@suse.com>
- update to 1.1.0
  * add versioneer
  * Bump to py3
  * Handle unknown ExtensionArrays with pickle
* Tue Jul 23 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 1.0.0:
  * no upstream changelog
* Mon Jun  3 2019 pgajdos@suse.com
- version update to 0.3.10
  * no upstream changelog
- use %%pytest macro
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Sun Mar 11 2018 sebix+novell.com@sebix.at
- Use %%license macro for license.
* Thu Nov  2 2017 arun@gmx.de
- specfile:
  * add LICENSE.txt to %%doc
- update to version 0.3.8:
  * BUG: Fixed serialization for Datetime with tz (#25)
  * Path management (#24)
  * Add LICENSE.txt to manifest. (#23)
  * `msgpack.packb` may not have packed utf-8 compatible bytes, so
    don't … (#22)
  * Fix pandas/numpy serialization (#21)
  * Handle categorical indices
* Wed Apr 19 2017 toddrme2178@gmail.com
- Update to version 0.3.7
- Only make hard requirements BuildRequires and Requires.
- Implement single-spec version.
* Tue Jul 14 2015 toddrme2178@gmail.com
- Initial version
